Reddit dataset, where TIFU denotes the name of subbreddit /r/tifu. As defined in
the publication, style "short" uses title as summary and "long" uses tldr as
summary.

Features includes:

  - document: post text without tldr.
  - tldr: tldr line.
  - title: trimmed title without tldr.
  - ups: upvotes.
  - score: score.
  - num_comments: number of comments.
  - upvote_ratio: upvote ratio.
